@@ -15,7 +15,7 @@ import time
 from textwrap import dedent
 from warnings import warn
 
-from qtconsole.qt import QtCore, QtGui
+from qtpy import QtCore, QtGui
 
 from IPython.lib.lexers import IPythonLexer, IPython3Lexer
 from pygments.lexers import get_lexer_by_name
@@ -149,8 +149,9 @@ class JupyterWidget(IPythonWidget):
         self.log.debug("complete: %s", rep.get('content', ''))
         cursor = self._get_cursor()
         info = self._request_info.get('complete')
-        if info and info.id == rep['parent_header']['msg_id'] and \
-                info.pos == cursor.position():
+        if (info and info.id == rep['parent_header']['msg_id']
+                and info.pos == self._get_input_buffer_cursor_pos()
+                and info.code == self.input_buffer):
             content = rep['content']
             matches = content['matches']
             start = content['cursor_start']
@@ -405,6 +406,10 @@ class JupyterWidget(IPythonWidget):
             # Update the prompt cursor
             self._prompt_cursor.setPosition(cursor.position() - 1)
 
+            # Store the updated prompt.
+            block = self._control.document().lastBlock()
+            length = len(self._prompt)
+            self._previous_prompt_obj = self._PromptBlock(block, length, new_prompt_number)
 
     def _show_interpreter_prompt_for_reply(self, msg):
         """ Reimplemented for IPython-style prompts.
